@@ -25,6 +25,8 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
         self._app = app
         self._apikey = apikey
         self._route_last_updated = {}
+        self._rate_limit_logs_sent = {}
+        
         for route in fastapi_app.router.routes:
             if type(route.app )== FastAPI:
                 for new_route in route.app.routes:
@@ -32,10 +34,12 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
                     edited_route = re.sub(r'\W+', '~', path)
                     self._log_dict[str(edited_route)] = {}
                     self._route_last_updated[str(edited_route)] = time.time()
+                    self._rate_limit_logs_sent[str(edited_route)] = 0
             else:
                 edited_route = re.sub(r'\W+', '~', route.path)
                 self._log_dict[str(edited_route)] = {}
                 self._route_last_updated[str(edited_route)] = time.time()
+                self._rate_limit_logs_sent[str(edited_route)] = 0
                 
 
     async def set_body(self, request: Request, body: bytes):
@@ -73,6 +77,26 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
         string = string.replace(",false", "False,")
         out=ast.literal_eval(string)
         return out
+    
+    async def _send_logs(self, route: str, header, body, query)-> None:
+        timestamp = time.time()
+        last_log_sent = self._rate_limit_logs_sent[route]
+        if timestamp - last_log_sent > 10:
+            print("called from here")
+            requests.post("https://backend.withsix.co/slack/send_message_to_slack_user", json=schemas.SlackMessageSchema(
+                header=header, 
+                user_id=self._apikey, 
+                body=str(body), 
+                query_args=str(query), 
+                timestamp=timestamp, 
+                attack_type="No Rate Limit Attack", 
+                cwe_link="https://cwe.mitre.org/data/definitions/770.html", 
+                status="MITIGATED", 
+                learn_more_link="https://en.wikipedia.org/wiki/Rate_limiting"
+            ).dict())
+            self._rate_limit_logs_sent[route]=timestamp
+            
+
         
     async def dispatch(self,request: Request,call_next) -> None:
         host = request.client.host
@@ -82,12 +106,13 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
         query_params = request.query_params
         rate_limit_resp = None
         status_code = 200
+
         
         
         #fail safe if there is an internal server error our servers are currenly in maintnance
         try:
-            if time.time() - self._route_last_updated[route] >5:
-                #update rate limit details every 5 seconds
+            if time.time() - self._route_last_updated[route] >60:
+                #update rate limit details every 60 seconds
                 rate_limit_resp = requests.get("https://backend.withsix.co/project-config/config/get-route-rate-limit/"+self._apikey+"/"+route)
                 self._route_last_updated[route] = time.time()
                 status_code = rate_limit_resp.status_code
@@ -129,6 +154,7 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
                             _response = await call_next(request)
                             return _response
                         else:
+                            await self._send_logs(route=route, header=headers, body=body, query=query_params)
                             temp_payload = rate_limit.error_payload.values()
                             final = {}
                             for c in temp_payload:
@@ -143,7 +169,7 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
                         _response = await call_next(request)
                         return _response
                 except Exception as e:
-                   
+                    print(e)
                     _response = await call_next(request)
                     return _response
             else:
@@ -151,6 +177,6 @@ class SixRateLimiterMiddleware(BaseHTTPMiddleware):
                 _response = await call_next(request)
                 return _response
         except Exception as e:
-            
+            print(e)
             _response = await call_next(request)
             return _response
\ No newline at end of file
